package com.auth.service.base.controller;

import com.auth.common.model.common.result.PageResult;
import com.auth.common.model.common.result.Result;
import com.auth.common.model.common.result.ResultCodeEnum;
import com.auth.dao.base.entity.DictEntity;
import com.auth.model.base.dto.DictDto;
import com.auth.model.base.vo.DictVo;
import com.auth.service.base.service.DictService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 系统数据字典 前端控制器
 * </p>
 *
 * @author AuthoritySystem
 * @since 2025-07-22 23:14:35
 */
@Tag(name = "系统数据字典", description = "系统数据字典相关接口")
@RestController
@RequestMapping("/api/v1/base/dict")
@RequiredArgsConstructor
public class DictController {

    private final DictService dictService;

    @PreAuthorize("auth.decide('dict:query')")
    @Operation(summary = "分页查询系统数据字典", description = "分页查询系统数据字典")
    @GetMapping()
    public Result<PageResult<DictVo>> getDictPage(DictDto dto) {
        Page<DictEntity> pageParams = new Page<>(dto.getPageIndex(), dto.getPageSize());
        PageResult<DictVo> pageResult = dictService.getDictPage(pageParams, dto);
        return Result.success(pageResult);
    }

    @PreAuthorize("auth.decide('dict:query')")
    @Operation(summary = "根据id查询系统数据字典详情", description = "根据id查询系统数据字典详情")
    @GetMapping("{id}")
    public Result<DictVo> getById(@PathVariable("id") Long id) {
        DictVo dictVo = dictService.getById(id);

        return Result.success(dictVo);
    }

    @PreAuthorize("auth.decide('dict:create')")
    @Operation(summary = "添加系统数据字典", description = "添加系统数据字典")
    @PostMapping()
    public Result<String> create(@Valid @RequestBody DictDto dto) {
        dictService.create(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @PreAuthorize("auth.decide('dict:update')")
    @Operation(summary = "更新系统数据字典", description = "更新系统数据字典")
    @PutMapping()
    public Result<String> update(@Valid @RequestBody DictDto dto) {
        dictService.update(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @PreAuthorize("auth.decide('dict:delete')")
    @Operation(summary = "删除系统数据字典", description = "删除系统数据字典")
    @DeleteMapping()
    public Result<String> batchDelete(@RequestBody List<Long> ids) {
        dictService.batchDelete(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}