package com.auth.service.base.controller;

import com.auth.common.model.common.result.PageResult;
import com.auth.common.model.common.result.Result;
import com.auth.common.model.common.result.ResultCodeEnum;
import com.auth.dao.base.entity.EmailConfigEntity;
import com.auth.model.base.dto.EmailConfigDto;
import com.auth.model.base.vo.EmailConfigVo;
import com.auth.service.base.service.EmailConfigService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 系统邮件服务器配置 前端控制器
 * </p>
 *
 * @author AuthoritySystem
 * @since 2025-07-22 23:14:35
 */
@Tag(name = "系统邮件服务器配置", description = "系统邮件服务器配置相关接口")
@RestController
@RequestMapping("/api/v1/base/email-config")
@RequiredArgsConstructor
public class EmailConfigController {

    private final EmailConfigService emailConfigService;

    @PreAuthorize("auth.decide('emailConfig:query')")
    @Operation(summary = "分页查询系统邮件服务器配置", description = "分页查询系统邮件服务器配置")
    @GetMapping()
    public Result<PageResult<EmailConfigVo>> getEmailConfigPage(EmailConfigDto dto) {
        Page<EmailConfigEntity> pageParams = new Page<>(dto.getPageIndex(), dto.getPageSize());
        PageResult<EmailConfigVo> pageResult = emailConfigService.getEmailConfigPage(pageParams, dto);
        return Result.success(pageResult);
    }

    @PreAuthorize("auth.decide('emailConfig:query')")
    @Operation(summary = "根据id查询系统邮件服务器配置详情", description = "根据id查询系统邮件服务器配置详情")
    @GetMapping("{id}")
    public Result<EmailConfigVo> getById(@PathVariable("id") Long id) {
        EmailConfigVo emailConfigVo = emailConfigService.getById(id);

        return Result.success(emailConfigVo);
    }

    @PreAuthorize("auth.decide('emailConfig:create')")
    @Operation(summary = "添加系统邮件服务器配置", description = "添加系统邮件服务器配置")
    @PostMapping()
    public Result<String> create(@Valid @RequestBody EmailConfigDto dto) {
        emailConfigService.create(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @PreAuthorize("auth.decide('emailConfig:update')")
    @Operation(summary = "更新系统邮件服务器配置", description = "更新系统邮件服务器配置")
    @PutMapping()
    public Result<String> update(@Valid @RequestBody EmailConfigDto dto) {
        emailConfigService.update(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @PreAuthorize("auth.decide('emailConfig:delete')")
    @Operation(summary = "删除系统邮件服务器配置", description = "删除系统邮件服务器配置")
    @DeleteMapping()
    public Result<String> batchDelete(@RequestBody List<Long> ids) {
        emailConfigService.batchDelete(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}