package com.auth.service.base.controller;

import com.auth.common.model.common.result.PageResult;
import com.auth.common.model.common.result.Result;
import com.auth.common.model.common.result.ResultCodeEnum;
import com.auth.dao.base.entity.LoginLogEntity;
import com.auth.model.base.dto.LoginLogDto;
import com.auth.model.base.vo.LoginLogVo;
import com.auth.service.base.service.LoginLogService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 系统用户登录日志 前端控制器
 * </p>
 *
 * @author AuthoritySystem
 * @since 2025-07-22 23:14:35
 */
@Tag(name = "系统用户登录日志", description = "系统用户登录日志相关接口")
@RestController
@RequestMapping("/api/v1/base/login-log")
@RequiredArgsConstructor
public class LoginLogController {

    private final LoginLogService loginLogService;

    @PreAuthorize("auth.decide('loginLog:query')")
    @Operation(summary = "分页查询系统用户登录日志", description = "分页查询系统用户登录日志")
    @GetMapping()
    public Result<PageResult<LoginLogVo>> getLoginLogPage(LoginLogDto dto) {
        Page<LoginLogEntity> pageParams = new Page<>(dto.getPageIndex(), dto.getPageSize());
        PageResult<LoginLogVo> pageResult = loginLogService.getLoginLogPage(pageParams, dto);
        return Result.success(pageResult);
    }

    @PreAuthorize("auth.decide('loginLog:query')")
    @Operation(summary = "根据id查询系统用户登录日志详情", description = "根据id查询系统用户登录日志详情")
    @GetMapping("{id}")
    public Result<LoginLogVo> getById(@PathVariable("id") Long id) {
        LoginLogVo loginLogVo = loginLogService.getById(id);

        return Result.success(loginLogVo);
    }

    @PreAuthorize("auth.decide('loginLog:create')")
    @Operation(summary = "添加系统用户登录日志", description = "添加系统用户登录日志")
    @PostMapping()
    public Result<String> create(@Valid @RequestBody LoginLogDto dto) {
        loginLogService.create(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @PreAuthorize("auth.decide('loginLog:update')")
    @Operation(summary = "更新系统用户登录日志", description = "更新系统用户登录日志")
    @PutMapping()
    public Result<String> update(@Valid @RequestBody LoginLogDto dto) {
        loginLogService.update(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @PreAuthorize("auth.decide('loginLog:delete')")
    @Operation(summary = "删除系统用户登录日志", description = "删除系统用户登录日志")
    @DeleteMapping()
    public Result<String> batchDelete(@RequestBody List<Long> ids) {
        loginLogService.batchDelete(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}