package com.auth.service.base.controller;

import com.auth.common.model.common.result.PageResult;
import com.auth.common.model.common.result.Result;
import com.auth.common.model.common.result.ResultCodeEnum;
import com.auth.dao.base.entity.MenuEntity;
import com.auth.model.base.dto.MenuDto;
import com.auth.model.base.vo.MenuVo;
import com.auth.service.base.service.MenuService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 系统菜单权限 前端控制器
 * </p>
 *
 * @author AuthoritySystem
 * @since 2025-07-22 23:14:35
 */
@Tag(name = "系统菜单权限", description = "系统菜单权限相关接口")
@RestController
@RequestMapping("/api/v1/base/menu")
@RequiredArgsConstructor
public class MenuController {

    private final MenuService menuService;

    @PreAuthorize("auth.decide('menu:query')")
    @Operation(summary = "分页查询系统菜单权限", description = "分页查询系统菜单权限")
    @GetMapping()
    public Result<PageResult<MenuVo>> getMenuPage(MenuDto dto) {
        Page<MenuEntity> pageParams = new Page<>(dto.getPageIndex(), dto.getPageSize());
        PageResult<MenuVo> pageResult = menuService.getMenuPage(pageParams, dto);
        return Result.success(pageResult);
    }

    @PreAuthorize("auth.decide('menu:query')")
    @Operation(summary = "根据id查询系统菜单权限详情", description = "根据id查询系统菜单权限详情")
    @GetMapping("{id}")
    public Result<MenuVo> getById(@PathVariable("id") Long id) {
        MenuVo menuVo = menuService.getById(id);

        return Result.success(menuVo);
    }

    @PreAuthorize("auth.decide('menu:create')")
    @Operation(summary = "添加系统菜单权限", description = "添加系统菜单权限")
    @PostMapping()
    public Result<String> create(@Valid @RequestBody MenuDto dto) {
        menuService.create(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @PreAuthorize("auth.decide('menu:update')")
    @Operation(summary = "更新系统菜单权限", description = "更新系统菜单权限")
    @PutMapping()
    public Result<String> update(@Valid @RequestBody MenuDto dto) {
        menuService.update(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @PreAuthorize("auth.decide('menu:delete')")
    @Operation(summary = "删除系统菜单权限", description = "删除系统菜单权限")
    @DeleteMapping()
    public Result<String> batchDelete(@RequestBody List<Long> ids) {
        menuService.batchDelete(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}