package com.auth.service.base.controller;

import com.auth.common.model.common.result.PageResult;
import com.auth.common.model.common.result.Result;
import com.auth.common.model.common.result.ResultCodeEnum;
import com.auth.dao.base.entity.MenuRoleEntity;
import com.auth.model.base.dto.MenuRoleDto;
import com.auth.model.base.vo.MenuRoleVo;
import com.auth.service.base.service.MenuRoleService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 系统菜单角色关联 前端控制器
 * </p>
 *
 * @author AuthoritySystem
 * @since 2025-07-22 23:14:35
 */
@Tag(name = "系统菜单角色关联", description = "系统菜单角色关联相关接口")
@RestController
@RequestMapping("/api/v1/base/menu-role")
@RequiredArgsConstructor
public class MenuRoleController {

    private final MenuRoleService menuRoleService;

    @PreAuthorize("auth.decide('menuRole:query')")
    @Operation(summary = "分页查询系统菜单角色关联", description = "分页查询系统菜单角色关联")
    @GetMapping()
    public Result<PageResult<MenuRoleVo>> getMenuRolePage(MenuRoleDto dto) {
        Page<MenuRoleEntity> pageParams = new Page<>(dto.getPageIndex(), dto.getPageSize());
        PageResult<MenuRoleVo> pageResult = menuRoleService.getMenuRolePage(pageParams, dto);
        return Result.success(pageResult);
    }

    @PreAuthorize("auth.decide('menuRole:query')")
    @Operation(summary = "根据id查询系统菜单角色关联详情", description = "根据id查询系统菜单角色关联详情")
    @GetMapping("{id}")
    public Result<MenuRoleVo> getById(@PathVariable("id") Long id) {
        MenuRoleVo menuRoleVo = menuRoleService.getById(id);

        return Result.success(menuRoleVo);
    }

    @PreAuthorize("auth.decide('menuRole:create')")
    @Operation(summary = "添加系统菜单角色关联", description = "添加系统菜单角色关联")
    @PostMapping()
    public Result<String> create(@Valid @RequestBody MenuRoleDto dto) {
        menuRoleService.create(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @PreAuthorize("auth.decide('menuRole:update')")
    @Operation(summary = "更新系统菜单角色关联", description = "更新系统菜单角色关联")
    @PutMapping()
    public Result<String> update(@Valid @RequestBody MenuRoleDto dto) {
        menuRoleService.update(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @PreAuthorize("auth.decide('menuRole:delete')")
    @Operation(summary = "删除系统菜单角色关联", description = "删除系统菜单角色关联")
    @DeleteMapping()
    public Result<String> batchDelete(@RequestBody List<Long> ids) {
        menuRoleService.batchDelete(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}