package com.auth.service.base.controller;

import com.auth.common.model.common.result.PageResult;
import com.auth.common.model.common.result.Result;
import com.auth.common.model.common.result.ResultCodeEnum;
import com.auth.dao.base.entity.OperationLogEntity;
import com.auth.model.base.dto.OperationLogDto;
import com.auth.model.base.vo.OperationLogVo;
import com.auth.service.base.service.OperationLogService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 系统操作日志 前端控制器
 * </p>
 *
 * @author AuthoritySystem
 * @since 2025-07-22 23:14:35
 */
@Tag(name = "系统操作日志", description = "系统操作日志相关接口")
@RestController
@RequestMapping("/api/v1/base/operation-log")
@RequiredArgsConstructor
public class OperationLogController {

    private final OperationLogService operationLogService;

    @PreAuthorize("auth.decide('operationLog:query')")
    @Operation(summary = "分页查询系统操作日志", description = "分页查询系统操作日志")
    @GetMapping()
    public Result<PageResult<OperationLogVo>> getOperationLogPage(OperationLogDto dto) {
        Page<OperationLogEntity> pageParams = new Page<>(dto.getPageIndex(), dto.getPageSize());
        PageResult<OperationLogVo> pageResult = operationLogService.getOperationLogPage(pageParams, dto);
        return Result.success(pageResult);
    }

    @PreAuthorize("auth.decide('operationLog:query')")
    @Operation(summary = "根据id查询系统操作日志详情", description = "根据id查询系统操作日志详情")
    @GetMapping("{id}")
    public Result<OperationLogVo> getById(@PathVariable("id") Long id) {
        OperationLogVo operationLogVo = operationLogService.getById(id);

        return Result.success(operationLogVo);
    }

    @PreAuthorize("auth.decide('operationLog:create')")
    @Operation(summary = "添加系统操作日志", description = "添加系统操作日志")
    @PostMapping()
    public Result<String> create(@Valid @RequestBody OperationLogDto dto) {
        operationLogService.create(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @PreAuthorize("auth.decide('operationLog:update')")
    @Operation(summary = "更新系统操作日志", description = "更新系统操作日志")
    @PutMapping()
    public Result<String> update(@Valid @RequestBody OperationLogDto dto) {
        operationLogService.update(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @PreAuthorize("auth.decide('operationLog:delete')")
    @Operation(summary = "删除系统操作日志", description = "删除系统操作日志")
    @DeleteMapping()
    public Result<String> batchDelete(@RequestBody List<Long> ids) {
        operationLogService.batchDelete(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}