package com.auth.service.base.controller;

import com.auth.common.model.common.result.PageResult;
import com.auth.common.model.common.result.Result;
import com.auth.common.model.common.result.ResultCodeEnum;
import com.auth.dao.base.entity.PermissionEntity;
import com.auth.model.base.dto.PermissionDto;
import com.auth.model.base.vo.PermissionVo;
import com.auth.service.base.service.PermissionService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 系统权限表 前端控制器
 * </p>
 *
 * @author AuthoritySystem
 * @since 2025-07-22 23:14:35
 */
@Tag(name = "系统权限表", description = "系统权限表相关接口")
@RestController
@RequestMapping("/api/v1/base/permission")
@RequiredArgsConstructor
public class PermissionController {

    private final PermissionService permissionService;

    @PreAuthorize("auth.decide('permission:query')")
    @Operation(summary = "分页查询系统权限表", description = "分页查询系统权限表")
    @GetMapping()
    public Result<PageResult<PermissionVo>> getPermissionPage(PermissionDto dto) {
        Page<PermissionEntity> pageParams = new Page<>(dto.getPageIndex(), dto.getPageSize());
        PageResult<PermissionVo> pageResult = permissionService.getPermissionPage(pageParams, dto);
        return Result.success(pageResult);
    }

    @PreAuthorize("auth.decide('permission:query')")
    @Operation(summary = "根据id查询系统权限表详情", description = "根据id查询系统权限表详情")
    @GetMapping("{id}")
    public Result<PermissionVo> getById(@PathVariable("id") Long id) {
        PermissionVo permissionVo = permissionService.getById(id);

        return Result.success(permissionVo);
    }

    @PreAuthorize("auth.decide('permission:create')")
    @Operation(summary = "添加系统权限表", description = "添加系统权限表")
    @PostMapping()
    public Result<String> create(@Valid @RequestBody PermissionDto dto) {
        permissionService.create(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @PreAuthorize("auth.decide('permission:update')")
    @Operation(summary = "更新系统权限表", description = "更新系统权限表")
    @PutMapping()
    public Result<String> update(@Valid @RequestBody PermissionDto dto) {
        permissionService.update(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @PreAuthorize("auth.decide('permission:delete')")
    @Operation(summary = "删除系统权限表", description = "删除系统权限表")
    @DeleteMapping()
    public Result<String> batchDelete(@RequestBody List<Long> ids) {
        permissionService.batchDelete(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}