package com.auth.service.base.controller;

import com.auth.common.model.common.result.PageResult;
import com.auth.common.model.common.result.Result;
import com.auth.common.model.common.result.ResultCodeEnum;
import com.auth.dao.base.entity.UserDeptEntity;
import com.auth.model.base.dto.UserDeptDto;
import com.auth.model.base.vo.UserDeptVo;
import com.auth.service.base.service.UserDeptService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 部门用户关系表 前端控制器
 * </p>
 *
 * @author AuthoritySystem
 * @since 2025-07-22 23:14:35
 */
@Tag(name = "部门用户关系表", description = "部门用户关系表相关接口")
@RestController
@RequestMapping("/api/v1/base/user-dept")
@RequiredArgsConstructor
public class UserDeptController {

    private final UserDeptService userDeptService;

    @PreAuthorize("auth.decide('userDept:query')")
    @Operation(summary = "分页查询部门用户关系表", description = "分页查询部门用户关系表")
    @GetMapping()
    public Result<PageResult<UserDeptVo>> getUserDeptPage(UserDeptDto dto) {
        Page<UserDeptEntity> pageParams = new Page<>(dto.getPageIndex(), dto.getPageSize());
        PageResult<UserDeptVo> pageResult = userDeptService.getUserDeptPage(pageParams, dto);
        return Result.success(pageResult);
    }

    @PreAuthorize("auth.decide('userDept:query')")
    @Operation(summary = "根据id查询部门用户关系表详情", description = "根据id查询部门用户关系表详情")
    @GetMapping("{id}")
    public Result<UserDeptVo> getById(@PathVariable("id") Long id) {
        UserDeptVo userDeptVo = userDeptService.getById(id);

        return Result.success(userDeptVo);
    }

    @PreAuthorize("auth.decide('userDept:create')")
    @Operation(summary = "添加部门用户关系表", description = "添加部门用户关系表")
    @PostMapping()
    public Result<String> create(@Valid @RequestBody UserDeptDto dto) {
        userDeptService.create(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @PreAuthorize("auth.decide('userDept:update')")
    @Operation(summary = "更新部门用户关系表", description = "更新部门用户关系表")
    @PutMapping()
    public Result<String> update(@Valid @RequestBody UserDeptDto dto) {
        userDeptService.update(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @PreAuthorize("auth.decide('userDept:delete')")
    @Operation(summary = "删除部门用户关系表", description = "删除部门用户关系表")
    @DeleteMapping()
    public Result<String> batchDelete(@RequestBody List<Long> ids) {
        userDeptService.batchDelete(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}