package com.auth.service.base.controller;

import com.auth.common.model.common.result.PageResult;
import com.auth.common.model.common.result.Result;
import com.auth.common.model.common.result.ResultCodeEnum;
import com.auth.dao.base.entity.UserRoleEntity;
import com.auth.model.base.dto.UserRoleDto;
import com.auth.model.base.vo.UserRoleVo;
import com.auth.service.base.service.UserRoleService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 系统用户角色关系表 前端控制器
 * </p>
 *
 * @author AuthoritySystem
 * @since 2025-07-22 23:14:35
 */
@Tag(name = "系统用户角色关系表", description = "系统用户角色关系表相关接口")
@RestController
@RequestMapping("/api/v1/base/user-role")
@RequiredArgsConstructor
public class UserRoleController {

    private final UserRoleService userRoleService;

    @PreAuthorize("auth.decide('userRole:query')")
    @Operation(summary = "分页查询系统用户角色关系表", description = "分页查询系统用户角色关系表")
    @GetMapping()
    public Result<PageResult<UserRoleVo>> getUserRolePage(UserRoleDto dto) {
        Page<UserRoleEntity> pageParams = new Page<>(dto.getPageIndex(), dto.getPageSize());
        PageResult<UserRoleVo> pageResult = userRoleService.getUserRolePage(pageParams, dto);
        return Result.success(pageResult);
    }

    @PreAuthorize("auth.decide('userRole:query')")
    @Operation(summary = "根据id查询系统用户角色关系表详情", description = "根据id查询系统用户角色关系表详情")
    @GetMapping("{id}")
    public Result<UserRoleVo> getById(@PathVariable("id") Long id) {
        UserRoleVo userRoleVo = userRoleService.getById(id);

        return Result.success(userRoleVo);
    }

    @PreAuthorize("auth.decide('userRole:create')")
    @Operation(summary = "添加系统用户角色关系表", description = "添加系统用户角色关系表")
    @PostMapping()
    public Result<String> create(@Valid @RequestBody UserRoleDto dto) {
        userRoleService.create(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @PreAuthorize("auth.decide('userRole:update')")
    @Operation(summary = "更新系统用户角色关系表", description = "更新系统用户角色关系表")
    @PutMapping()
    public Result<String> update(@Valid @RequestBody UserRoleDto dto) {
        userRoleService.update(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @PreAuthorize("auth.decide('userRole:delete')")
    @Operation(summary = "删除系统用户角色关系表", description = "删除系统用户角色关系表")
    @DeleteMapping()
    public Result<String> batchDelete(@RequestBody List<Long> ids) {
        userRoleService.batchDelete(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}